;*************************************************************************
;				Constant definitions
;-------------------------------------------------------------------------
.equ	xtal		= 8000000		;8MHz
.equ	boottime	= byte3( xtal / 5 )	;0.2s

.equ	xpage		= 512		;super page size

.equ	Key_Enter	= 0x0A		;Command end
.equ	Key_LineFeed	= 0x0D		;also command end

.equ	Key_Done        = 'a'		;Command execution successful
.equ	Key_Failed      = 'f'		;Command failed or not avaiable
.equ	Key_Continue	= 'c'		;read or write next byte

;-------------------------------------------------------------------------
;				Using register
;-------------------------------------------------------------------------
.def	spmreg_lo	= r0		;used by SPM
.def	spmreg_hi	= r1		;used by SPM
					;auto baud usage:
.def	b4		= r2		;last low level duration
.def	b5		= r3
.def	st1l		= r4		;software time correction
.def	st1h		= r5
					;programming usage:
.def	crc_lo		= r6		;crc
.def	crc_hi		= r7
.def	poly_lo		= r8		;crc polynom
.def	poly_hi		= r9

.def	paddrl		= r10		;lowest program address
.def	paddrh		= r11

.def	SaveSreg	= r13		;for interrupts only
.def	rx_ptr		= r14		;rx data pointer
.def	pbyte		= r15		;byte to program

;-------------------------------------------------------------------------
.def	ia0		= r16		;interrupt working registers

.def	flags		= r17
.equ	f_enable	= 0
.equ	f_error		= 1
.equ	f_eeprom	= 2
.equ	f_write		= 3
.equ	f_verify	= 4

.def	a0		= r18		;working registers
.def	a1		= r19
.def	a2		= r20
.def	a3		= r21
.def	timeout		= r22		;boot start time counter
.def	addrxh		= r23		;M128 extension
.def	addrl		= r24
.def	addrh		= r25
;-------------------------------------------------------------------------
;				Using SRAM
;-------------------------------------------------------------------------
.dseg
	.org		RAMSTART
sram1:
	.org		(sram1 + 0xFF) & 0xFF00		;buffer alignment
.equ	Rx_Size		= 256
Rx_Buff:	.byte	Rx_Size
Rx_Buff_End:
xpage_buff:	.byte	xpage
xpage_buff_end:
.cseg
;-------------------------------------------------------------------------
;				Port definitions
;-------------------------------------------------------------------------
.equ	led_out		= PORTB		;LEDs
.equ	led_ddr		= DDRB
.equ	led0		= PORTB0
.equ	led1		= PORTB1
.equ	led2		= PORTB2
.equ	led5		= PORTB5

.equ	UART_IN		= PIND
.equ	RXD		= PORTD0
;-------------------------------------------------------------------------
